{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf mkMerge mkThenElse;
  annuaire = config.r6d.machines;
  currentMachine = annuaire."${config.networking.fqdn}";
  flags = currentMachine.configurationFlags;
in

mkIf true {

  # Paquets
  environment.systemPackages = with pkgs; [
      byobu         # permet de se déconnecter d'un terminal sans l'arréter
      tig gti lazygit # outil de gestion de version
      gnumake       # pour décrire les recettes de compilation
      gnupg         # GPG
      htop          # monitoring
      lsb-release   # pour les scripts qui utilisent cet outil (dont byobu)
      #libressl      # librairie pour faire du TLS et les algorithmes de crypto par OpenBSD
      ncdu          # outil pour voir l'espace utilisé
      p7zip         # compression de fichier
      parted        # partitionnement de disque
      pciutils
      pinentry      # pour taper les mots de passe gpg
      psmisc        # fournis les utilitaires comme killall, fuser, pstree
      #python        # python -- python -m SimpleHTTPServer 8000
      shared-mime-info  # MIME info
      tmux          # nécessaire pour byobu
      tree          # affiche une arborescence de fichiers et dossiers
      usbutils
      wget          # client HTTP console
      which         # pour connaitre le chemin d'un exécutable
      helix         # Éditeur post-moderne
      nil           # LSP pour Nix
      nodePackages.bash-language-server # LSP pour Bash
      delta         # visionneur de différences
  ];
  programs = {
    gnupg.agent.enable = true;
    git = {
      enable = true;
      package = pkgs.gitFull;
      config = {
        # http://www.git-attitude.fr/2014/09/15/30-options-git-qui-gagnent-a-etre-connues/
        color = {
          diff = "auto";
          branch = "auto";
          interactive = "auto";
          pager = true;
          showbranch = "auto";
          status = "auto";
        };
        alias = {
          a  = "add -p";
          br = "for-each-ref --sort=committerdate refs/heads/ --format='%(committerdate:short)\t%(authorname)\t%(refname:short)'";
          ci = "commit";
          co = "checkout";
          ff = "pull --ff-only";
          oops = "commit --amend --no-edit";
          # Show files ignored by git
          ignored = "ls-files -o -i --exclude-standard";
          ls = "ls-files";
          st = "status";
          # Logs
          lol = "log --graph --decorate --pretty=oneline --abbrev-commit";
          lola = "log --graph --decorate --pretty=oneline --abbrev-commit --all";
          not-pushed = "log --branches --not --remotes";
        };
        push.default = "simple";
        code.editor = "${pkgs.vim_configurable}/bin/vim";
      };
      lfs.enable = true;
    };
  };
}
